==> m2m-qvtoml-SDK-1.0.0.zip: org/eclipse/m2m/internal/qvt/oml/editor/ui/completion/CategoryImageConstants.java <==
/*******************************************************************************
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *   
 * Contributors:
 *     Borland Software Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.m2m.internal.qvt.oml.editor.ui.completion;

/**
 * @author vrepeshko
 */
public class CategoryImageConstants {
    public static final String CLASSIFIER = "cat-classifier"; //$NON-NLS-1$
    public static final String KEYWORD = "cat-keyword"; //$NON-NLS-1$
    public static final String MAPPING = "cat-mapping"; //$NON-NLS-1$
    public static final String IMPERATIVE_OPERATION = "cat-imperative-operation"; //$NON-NLS-1$
    public static final String TYPE = "cat-type"; //$NON-NLS-1$
    public static final String OPERATION = "cat-operation"; //$NON-NLS-1$
    public static final String PROPERTY = "cat-property"; //$NON-NLS-1$
    public static final String VARIABLE = "cat-variable"; //$NON-NLS-1$
    public static final String PACKAGE = "cat-package"; //$NON-NLS-1$
    public static final String CLASS = "cat-class"; //$NON-NLS-1$
    public static final String DATATYPE = "cat-datatype"; //$NON-NLS-1$
    public static final String ENUM = "cat-enum"; //$NON-NLS-1$
    public static final String ENUM_LITERAL = "cat-enum-literal"; //$NON-NLS-1$
    public static final String MODELTYPE = "cat-modeltype"; //$NON-NLS-1$
    public static final String READONLY = "cat-readonly"; //$NON-NLS-1$
}

==> m2m-qvtoml-SDK-2.0.1.zip: org/eclipse/m2m/internal/qvt/oml/editor/ui/completion/CategoryImageConstants.java <==
/*******************************************************************************
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *   
 * Contributors:
 *     Borland Software Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.m2m.internal.qvt.oml.editor.ui.completion;

/**
 * @author vrepeshko
 */
public class CategoryImageConstants {
    public static final String CLASSIFIER = "cat-classifier"; //$NON-NLS-1$
    public static final String KEYWORD = "cat-keyword"; //$NON-NLS-1$
    public static final String MAPPING = "cat-mapping"; //$NON-NLS-1$
    public static final String IMPERATIVE_OPERATION = "cat-imperative-operation"; //$NON-NLS-1$
    public static final String TYPE = "cat-type"; //$NON-NLS-1$
    public static final String OPERATION = "cat-operation"; //$NON-NLS-1$
    public static final String PROPERTY = "cat-property"; //$NON-NLS-1$
    public static final String VARIABLE = "cat-variable"; //$NON-NLS-1$
    public static final String PACKAGE = "cat-package"; //$NON-NLS-1$
    public static final String CLASS = "cat-class"; //$NON-NLS-1$
    public static final String DATATYPE = "cat-datatype"; //$NON-NLS-1$
    public static final String ENUM = "cat-enum"; //$NON-NLS-1$
    public static final String ENUM_LITERAL = "cat-enum-literal"; //$NON-NLS-1$
    public static final String MODELTYPE = "cat-modeltype"; //$NON-NLS-1$
    public static final String READONLY = "cat-readonly"; //$NON-NLS-1$
    public static final String TEMPLATE = "cat-template"; //$NON-NLS-1$
    public static final String QVT_QUERY = "qvt-query"; //$NON-NLS-1$
    public static final String QVT_MAPPING = "qvt-mapping"; //$NON-NLS-1$
    public static final String QVT_SRC_FILE = "qvt_src_file"; //$NON-NLS-1$
}
